@@ -3,11 +3,20 @@
 compile_rcpp_attributes <- function(path = ".") {
   path <- pkg_path(path)
 
-  deps <- desc::desc_get_deps(file.path(path, "DESCRIPTION"))
-  links_to_rcpp <- any(deps$type == "LinkingTo" & deps$package == "Rcpp")
-
-  if (links_to_rcpp) {
+  if (pkg_links_to_rcpp(path)) {
     unlink(file.path(path, c("R/RcppExports.R", "src/RcppExports.cpp")))
     Rcpp::compileAttributes(path)
   }
 }
+
+#' Test if a package path is linking to Rcpp
+#' @inheritParams build
+#' @export
+#' @keywords internal
+pkg_links_to_rcpp <- function(path) {
+  path <- pkg_path(path)
+
+  deps <- desc::desc_get_deps(file.path(path, "DESCRIPTION"))
+
+  any(deps$type == "LinkingTo" & deps$package == "Rcpp")
+}
